This is a convenience wrapper for news$new(). If you already have a
NEWS file you can add it's path to newsmd().
Usage
newsmd(
file = NULL,
text = c(paste0("## version ", version), "", "---", "", "### NEWS.md setup", "",
"- added NEWS.md creation with [newsmd](https://github.com/Dschaykib/newsmd)", ""),
version = "0.0.0.9000"
)
Arguments
file
name of the NEWS file to load. If not given a new
file NEWS.md is created.
text
a character scalar containing the initial text.
version
a character with the version in the format
major.minor.patch.dev.
Details
This functions creates a news object, which can be saved as the
NEWS.md file with the internal method write(). One can add versions,
subtitles and bullet points to the news.
If an existing NEWS.md file is given, the version is extracted with
get_version and the dev part is bumped up.